@@ -8,7 +8,7 @@ from torch.autograd import Variable
 import torch.utils.model_zoo as model_zoo
 from UNet import *
 from UNetPP import *
-from PointNet import *
+from PointNet.PointNet import *
 from StackGAN import *
 from CharCNN import *
 from PSPNet import *
